@echo off

rem *** Configuration block ***

set BASE_DIR=c:\fab\certificates
set OPENSSL_BIN=c:\Program Files (x86)\OpenSSL-Win32\bin\
set OPENSSL_CONF=%BASE_DIR%\openssl.conf
set COUNTRY_CODE=XX
set CA_NAME=MyCAName
set ORGANIZATION_UNIT=MyOrganizationUnit
set ORGANIZATION=MyOrganization
set COMMON_NAME=fabcomputer.de.fab-online.com
set PASSPHRASE=password
set DAYS=730

rem *** End configuration block ***

set RootSUBJECT="/CN=%CA_NAME%/OU=%ORGANIZATION_UNIT%/O=%ORGANIZATION%/C=%COUNTRY_CODE%"
set ServerSUBJECT="/CN=%COMMON_NAME%"

@echo.
@echo Building certificates

@echo.
echo Delete existing files; keep Root CA (root*.*) and Serials (*.srl)
if exist ServerKey.pem   del ServerKey.pem
if exist ServerReq.pem   del ServerReq.pem
if exist Server.pem      del Server.pem

if exist RootKey.pem goto buildServer

@echo.
echo Create the root CA
"%OPENSSL_BIN%\OpenSSL" req -x509 -newkey rsa:4096 -sha256 -keyout RootKey.pem -out RootCert.pem -passin pass:%PASSPHRASE% -passout pass:%PASSPHRASE% -text -subj %RootSUBJECT% -config "%OPENSSL_CONF%" -days %DAYS% -extensions v3_ca
type RootCert.pem >Root.pem
type RootKey.pem >>Root.pem

:buildServer

@echo.
echo Create the server's certificate and sign it with the root CA                                                                                                    
"%OPENSSL_BIN%\OpenSSL" req -x509 -newkey rsa:4096 -sha256 -keyout ServerKey.pem -out ServerCert.pem -passin pass:%PASSPHRASE% -passout pass:%PASSPHRASE% -text -subj %ServerSUBJECT% -addext "subjectAltName = DNS:%COMMON_NAME%" -config "%OPENSSL_CONF%" -CA RootCert.pem -CAkey RootKey.pem -verbose -days %DAYS% -extensions v3_ca

"%OPENSSL_BIN%\OpenSSL" pkcs12 -export -out Server.pfx -inkey ServerKey.pem -in ServerCert.pem -certfile RootCert.pem -passin pass:%PASSPHRASE% -passout pass:%PASSPHRASE% 

type ServerCert.pem >Server.pem
type ServerKey.pem >>Server.pem
type RootCert.pem >>Server.pem

@echo.

@echo Hit RETURN to terminate
pause
